==> nhc98src-1.18.tar.gz: nhc98-1.18/src/prelude/Char/IntToDigit.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define v193	((void*)startLabel+61)
#define v195	((void*)startLabel+116)
#define v197	((void*)startLabel+132)
#define CT_v200	((void*)startLabel+156)
#define FN_LAMBDA189	((void*)startLabel+224)
#define CT_v203	((void*)startLabel+256)
#define CF_LAMBDA189	((void*)startLabel+264)
#define FN_LAMBDA188	((void*)startLabel+276)
#define CT_v206	((void*)startLabel+308)
#define CF_LAMBDA188	((void*)startLabel+316)
#define ST_v199	((void*)startLabel+320)
#define ST_v205	((void*)startLabel+336)
#define ST_v204	((void*)startLabel+365)
#define ST_v201	((void*)startLabel+393)
#define ST_v202	((void*)startLabel+419)
extern Node TM_Char[];
extern Node FN_Prelude_46Ord_46Prelude_46Int_46_62_61[];
extern Node FN_Prelude_46Ord_46Prelude_46Int_46_60_61[];
extern Node FN_Prelude_46_38_38[];
extern Node FN_Char_46ord[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Num_46Prelude_46Int_46_43[];
extern Node FN_Char_46chr[];
extern Node FN_Prelude_46Num_46Prelude_46Int_46_45[];
extern Node CF_Prelude_46otherwise[];
extern Node FN_Prelude_46error[];
extern Node TMSUB_Char[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v200)
,};
Node FN_Char_46intToDigit[] = {
  useLabel(TM_Char)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
, bytes2word(HEAP_INT_P1,0,HEAP_CVAL_I4,HEAP_ARG)
, bytes2word(1,HEAP_INT_P1,9,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I5,HEAP_OFF_N1,7,HEAP_OFF_N1)
, bytes2word(5,EVAL,NEEDHEAP_I32,JUMPFALSE)
, bytes2word(29,0,HEAP_CVAL_P1,6)
, bytes2word(HEAP_CVAL_P1,7,HEAP_OFF_N1,2)
, bytes2word(HEAP_CHAR_P1,48,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(8,HEAP_OFF_N1,4,HEAP_ARG)
, bytes2word(1,PUSH_P1,0,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,9,ZAP_STACK_P1,2)
, bytes2word(EVAL,NEEDHEAP_I32,APPLY,1)
,	/* v193: (byte 1) */
  bytes2word(RETURN_EVAL,HEAP_CVAL_I3,HEAP_ARG,1)
, bytes2word(HEAP_INT_P1,10,HEAP_CVAL_I4,HEAP_ARG)
, bytes2word(1,HEAP_INT_P1,15,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I5,HEAP_OFF_N1,7,HEAP_OFF_N1)
, bytes2word(5,EVAL,NEEDHEAP_I32,JUMPFALSE)
, bytes2word(36,0,HEAP_CVAL_P1,6)
, bytes2word(HEAP_CVAL_P1,7,HEAP_OFF_N1,2)
, bytes2word(HEAP_CHAR_P1,97,HEAP_CVAL_P1,8)
, bytes2word(HEAP_OFF_N1,4,HEAP_ARG,1)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,10,HEAP_OFF_N1)
, bytes2word(4,HEAP_INT_P1,10,PUSH_P1)
, bytes2word(0,PUSH_HEAP,HEAP_CVAL_P1,9)
, bytes2word(ZAP_ARG_I1,ZAP_STACK_P1,2,EVAL)
,	/* v195: (byte 4) */
  bytes2word(NEEDHEAP_I32,APPLY,1,RETURN_EVAL)
, bytes2word(PUSH_CVAL_P1,11,ZAP_ARG_I1,EVAL)
, bytes2word(NEEDHEAP_I32,JUMPFALSE,10,0)
, bytes2word(HEAP_CVAL_P1,12,PUSH_HEAP,HEAP_CVAL_P1)
,	/* v197: (byte 4) */
  bytes2word(13,HEAP_OFF_N1,2,RETURN_EVAL)
, bytes2word(HEAP_CVAL_P1,14,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(13,HEAP_OFF_N1,2,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 80001
, useLabel(ST_v199)
,	/* CT_v200: (byte 0) */
  HW(12,1)
, 0
,};
Node F0_Char_46intToDigit[] = {
  CAPTAG(useLabel(FN_Char_46intToDigit),1)
, VAPTAG(useLabel(FN_Prelude_46Ord_46Prelude_46Int_46_62_61))
, VAPTAG(useLabel(FN_Prelude_46Ord_46Prelude_46Int_46_60_61))
, VAPTAG(useLabel(FN_Prelude_46_38_38))
, VAPTAG(useLabel(FN_Char_46ord))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, VAPTAG(useLabel(FN_Prelude_46Num_46Prelude_46Int_46_43))
, VAPTAG(useLabel(FN_Char_46chr))
, VAPTAG(useLabel(FN_Prelude_46Num_46Prelude_46Int_46_45))
, useLabel(CF_Prelude_46otherwise)
, VAPTAG(useLabel(FN_LAMBDA188))
, VAPTAG(useLabel(FN_Prelude_46error))
, VAPTAG(useLabel(FN_LAMBDA189))
, bytes2word(0,0,0,0)
, useLabel(CT_v203)
,	/* FN_LAMBDA189: (byte 0) */
  useLabel(TMSUB_Char)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v202)
, 80001
, useLabel(ST_v201)
,	/* CT_v203: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA189: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA189))
, bytes2word(0,0,0,0)
, useLabel(CT_v206)
,	/* FN_LAMBDA188: (byte 0) */
  useLabel(TMSUB_Char)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v205)
, 110033
, useLabel(ST_v204)
,	/* CT_v206: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA188: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA188))
,	/* ST_v199: (byte 0) */
  bytes2word(67,104,97,114)
, bytes2word(46,105,110,116)
, bytes2word(84,111,68,105)
,	/* ST_v205: (byte 4) */
  bytes2word(103,105,116,0)
, bytes2word(67,104,97,114)
, bytes2word(46,105,110,116)
, bytes2word(84,111,68,105)
, bytes2word(103,105,116,58)
, bytes2word(32,110,111,116)
, bytes2word(32,97,32,100)
, bytes2word(105,103,105,116)
,	/* ST_v204: (byte 1) */
  bytes2word(0,67,104,97)
, bytes2word(114,46,105,110)
, bytes2word(116,84,111,68)
, bytes2word(105,103,105,116)
, bytes2word(58,49,49,58)
, bytes2word(51,51,45,49)
, bytes2word(49,58,54,50)
,	/* ST_v201: (byte 1) */
  bytes2word(0,67,104,97)
, bytes2word(114,46,105,110)
, bytes2word(116,84,111,68)
, bytes2word(105,103,105,116)
, bytes2word(58,56,58,49)
, bytes2word(45,49,49,58)
,	/* ST_v202: (byte 3) */
  bytes2word(54,50,0,67)
, bytes2word(104,97,114,58)
, bytes2word(32,80,97,116)
, bytes2word(116,101,114,110)
, bytes2word(32,109,97,116)
, bytes2word(99,104,32,102)
, bytes2word(97,105,108,117)
, bytes2word(114,101,32,105)
, bytes2word(110,32,102,117)
, bytes2word(110,99,116,105)
, bytes2word(111,110,32,97)
, bytes2word(116,32,56,58)
, bytes2word(49,45,49,49)
, bytes2word(58,54,50,46)
, bytes2word(0,0,0,0)
,};

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/prelude/Char/IntToDigit.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define v198	((void*)startLabel+61)
#define v200	((void*)startLabel+116)
#define v202	((void*)startLabel+132)
#define CT_v205	((void*)startLabel+156)
#define FN_LAMBDA194	((void*)startLabel+228)
#define CT_v208	((void*)startLabel+260)
#define CF_LAMBDA194	((void*)startLabel+268)
#define FN_LAMBDA193	((void*)startLabel+280)
#define CT_v211	((void*)startLabel+312)
#define CF_LAMBDA193	((void*)startLabel+320)
#define ST_v204	((void*)startLabel+324)
#define ST_v210	((void*)startLabel+340)
#define ST_v209	((void*)startLabel+369)
#define ST_v206	((void*)startLabel+397)
#define ST_v207	((void*)startLabel+423)
extern Node TM_Char[];
extern Node FN_Prelude_46Ord_46Prelude_46Int_46_62_61[];
extern Node FN_Prelude_46Ord_46Prelude_46Int_46_60_61[];
extern Node FN_Prelude_46_38_38[];
extern Node FN_Char_46ord[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Num_46Prelude_46Int_46_43[];
extern Node FN_Char_46chr[];
extern Node FN_Prelude_46Num_46Prelude_46Int_46_45[];
extern Node CF_Prelude_46otherwise[];
extern Node FN_Prelude_46error[];
extern Node FN_NHC_46Internal_46_95patternMatchFail[];
extern Node TMSUB_Char[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v205)
,};
Node FN_Char_46intToDigit[] = {
  useLabel(TM_Char)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
, bytes2word(HEAP_INT_P1,0,HEAP_CVAL_I4,HEAP_ARG)
, bytes2word(1,HEAP_INT_P1,9,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I5,HEAP_OFF_N1,7,HEAP_OFF_N1)
, bytes2word(5,EVAL,NEEDHEAP_I32,JUMPFALSE)
, bytes2word(29,0,HEAP_CVAL_P1,6)
, bytes2word(HEAP_CVAL_P1,7,HEAP_OFF_N1,2)
, bytes2word(HEAP_CHAR_P1,48,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(8,HEAP_OFF_N1,4,HEAP_ARG)
, bytes2word(1,PUSH_P1,0,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,9,ZAP_STACK_P1,2)
, bytes2word(EVAL,NEEDHEAP_I32,APPLY,1)
,	/* v198: (byte 1) */
  bytes2word(RETURN_EVAL,HEAP_CVAL_I3,HEAP_ARG,1)
, bytes2word(HEAP_INT_P1,10,HEAP_CVAL_I4,HEAP_ARG)
, bytes2word(1,HEAP_INT_P1,15,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I5,HEAP_OFF_N1,7,HEAP_OFF_N1)
, bytes2word(5,EVAL,NEEDHEAP_I32,JUMPFALSE)
, bytes2word(36,0,HEAP_CVAL_P1,6)
, bytes2word(HEAP_CVAL_P1,7,HEAP_OFF_N1,2)
, bytes2word(HEAP_CHAR_P1,97,HEAP_CVAL_P1,8)
, bytes2word(HEAP_OFF_N1,4,HEAP_ARG,1)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,10,HEAP_OFF_N1)
, bytes2word(4,HEAP_INT_P1,10,PUSH_P1)
, bytes2word(0,PUSH_HEAP,HEAP_CVAL_P1,9)
, bytes2word(ZAP_ARG_I1,ZAP_STACK_P1,2,EVAL)
,	/* v200: (byte 4) */
  bytes2word(NEEDHEAP_I32,APPLY,1,RETURN_EVAL)
, bytes2word(PUSH_CVAL_P1,11,ZAP_ARG_I1,EVAL)
, bytes2word(NEEDHEAP_I32,JUMPFALSE,10,0)
, bytes2word(HEAP_CVAL_P1,12,PUSH_HEAP,HEAP_CVAL_P1)
,	/* v202: (byte 4) */
  bytes2word(13,HEAP_OFF_N1,2,RETURN_EVAL)
, bytes2word(HEAP_CVAL_P1,14,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(15,HEAP_OFF_N1,2,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 80001
, useLabel(ST_v204)
,	/* CT_v205: (byte 0) */
  HW(13,1)
, 0
,};
Node F0_Char_46intToDigit[] = {
  CAPTAG(useLabel(FN_Char_46intToDigit),1)
, VAPTAG(useLabel(FN_Prelude_46Ord_46Prelude_46Int_46_62_61))
, VAPTAG(useLabel(FN_Prelude_46Ord_46Prelude_46Int_46_60_61))
, VAPTAG(useLabel(FN_Prelude_46_38_38))
, VAPTAG(useLabel(FN_Char_46ord))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, VAPTAG(useLabel(FN_Prelude_46Num_46Prelude_46Int_46_43))
, VAPTAG(useLabel(FN_Char_46chr))
, VAPTAG(useLabel(FN_Prelude_46Num_46Prelude_46Int_46_45))
, useLabel(CF_Prelude_46otherwise)
, VAPTAG(useLabel(FN_LAMBDA193))
, VAPTAG(useLabel(FN_Prelude_46error))
, VAPTAG(useLabel(FN_LAMBDA194))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95patternMatchFail))
, bytes2word(0,0,0,0)
, useLabel(CT_v208)
,	/* FN_LAMBDA194: (byte 0) */
  useLabel(TMSUB_Char)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v207)
, 80001
, useLabel(ST_v206)
,	/* CT_v208: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA194: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA194))
, bytes2word(0,0,0,0)
, useLabel(CT_v211)
,	/* FN_LAMBDA193: (byte 0) */
  useLabel(TMSUB_Char)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v210)
, 110033
, useLabel(ST_v209)
,	/* CT_v211: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA193: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA193))
,	/* ST_v204: (byte 0) */
  bytes2word(67,104,97,114)
, bytes2word(46,105,110,116)
, bytes2word(84,111,68,105)
,	/* ST_v210: (byte 4) */
  bytes2word(103,105,116,0)
, bytes2word(67,104,97,114)
, bytes2word(46,105,110,116)
, bytes2word(84,111,68,105)
, bytes2word(103,105,116,58)
, bytes2word(32,110,111,116)
, bytes2word(32,97,32,100)
, bytes2word(105,103,105,116)
,	/* ST_v209: (byte 1) */
  bytes2word(0,67,104,97)
, bytes2word(114,46,105,110)
, bytes2word(116,84,111,68)
, bytes2word(105,103,105,116)
, bytes2word(58,49,49,58)
, bytes2word(51,51,45,49)
, bytes2word(49,58,54,50)
,	/* ST_v206: (byte 1) */
  bytes2word(0,67,104,97)
, bytes2word(114,46,105,110)
, bytes2word(116,84,111,68)
, bytes2word(105,103,105,116)
, bytes2word(58,56,58,49)
, bytes2word(45,49,49,58)
,	/* ST_v207: (byte 3) */
  bytes2word(54,50,0,67)
, bytes2word(104,97,114,58)
, bytes2word(32,80,97,116)
, bytes2word(116,101,114,110)
, bytes2word(32,109,97,116)
, bytes2word(99,104,32,102)
, bytes2word(97,105,108,117)
, bytes2word(114,101,32,105)
, bytes2word(110,32,102,117)
, bytes2word(110,99,116,105)
, bytes2word(111,110,32,97)
, bytes2word(116,32,56,58)
, bytes2word(49,45,49,49)
, bytes2word(58,54,50,46)
, bytes2word(0,0,0,0)
,};
